@@ -8,7 +8,8 @@ class CopyRow(RowEvent):
     """
     Copy copy_from -> copy_to (e.g., auditing).
     """
-    def __init__(self, copy_from: object,
+    def __init__(self,
+                 copy_from: object,
                  copy_to: object,  # eg, PaymentAllocation (junction)
                  copy_when: Callable = None,
                  initialize_target: Callable = None):
@@ -30,8 +31,6 @@ class CopyRow(RowEvent):
         """
         Called by logic engine, overriding generic EarlyEvent rule.
 
-        Creates allocation row for each recipient until while_calling_allocator returns false
-
         :return:
         """
         copy_from = logic_row
